Documentation
¶
Overview ¶
Package format provides ASCII formatting for Linear resources. This is a token-efficient alternative to Markdown templates.
Index ¶
- type Format
- type Formatter
- func (f *Formatter) Comment(comment *linear.Comment) string
- func (f *Formatter) CommentList(comments []linear.Comment, page *Pagination) string
- func (f *Formatter) Cycle(cycle *linear.Cycle, fmt Format) string
- func (f *Formatter) CycleAnalysis(analysis *linear.CycleAnalysis, teamName, assigneeName string, ...) string
- func (f *Formatter) CycleList(cycles []linear.Cycle, fmt Format, page *Pagination) string
- func (f *Formatter) Issue(issue *linear.Issue, fmt Format) string
- func (f *Formatter) IssueList(issues []linear.Issue, fmt Format, page *Pagination) string
- func (f *Formatter) Project(project *linear.Project) string
- func (f *Formatter) ProjectList(projects []linear.Project, page *Pagination) string
- func (f *Formatter) Team(team *linear.Team) string
- func (f *Formatter) TeamList(teams []linear.Team, page *Pagination) string
- func (f *Formatter) User(user *linear.User) string
- func (f *Formatter) UserList(users []linear.User, page *Pagination) string
- type Pagination
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Format ¶
type Format string
Format specifies the level of detail in formatted output
func ParseFormat ¶
ParseFormat parses a string into a Format with validation
type Formatter ¶
type Formatter struct{}
Formatter formats Linear resources as ASCII text
func (*Formatter) CommentList ¶
func (f *Formatter) CommentList(comments []linear.Comment, page *Pagination) string
CommentList formats a list of comments with optional pagination
func (*Formatter) CycleAnalysis ¶
func (f *Formatter) CycleAnalysis(analysis *linear.CycleAnalysis, teamName, assigneeName string, showRecommendation bool) string
CycleAnalysis formats cycle analytics data
func (*Formatter) ProjectList ¶
func (f *Formatter) ProjectList(projects []linear.Project, page *Pagination) string
ProjectList formats a list of projects with optional pagination
func (*Formatter) TeamList ¶
func (f *Formatter) TeamList(teams []linear.Team, page *Pagination) string
TeamList formats a list of teams with optional pagination
type Pagination ¶
type Pagination struct {
Start int // Starting position (0-indexed)
Limit int // Items per page
Count int // Items in this page
TotalCount int // Total items
HasNextPage bool // More results exist
// Deprecated: Use offset-based pagination instead
EndCursor string // Cursor for cursor-based pagination
}
Pagination holds pagination metadata for list responses
Click to show internal directories.
Click to hide internal directories.